import { Token, MatchPrefix } from './tokens';
/**
 * The lexer turns input into a list of tokens.
 */
export declare class Lexer implements IterableIterator<Token> {
    private readonly input;
    private quotes;
    private position;
    /**
     * @param input - Input string.
     */
    constructor(input: string);
    /**
     * Sets the quotes to use.
     * This can be done in the middle of lexing.
     * @param quotes - List of pairs of open and close quotes.
     * @returns The lexer.
     */
    setQuotes(quotes: [string, string][]): this;
    /**
     * Whether the lexer is finished.
     */
    get finished(): boolean;
    private match;
    private matchR;
    private shift;
    /**
     * Gets the next token.
     * @returns An iterator result containing the next token.
     */
    next(): IteratorResult<Token>;
    private nextToken;
    private pWs;
    private pQuoted;
    private pWord;
    [Symbol.iterator](): this;
    /**
     * Runs the lexer.
     * This consumes the lexer.
     * @returns All the tokens lexed.
     */
    lex(): Token[];
    /**
     * Runs the lexer, matching a prefix and command.
     * This consumes at most two tokens of the lexer.
     * @param matchPrefix - A function that gives the length of the prefix if there is one.
     * @returns The command and the rest of the lexed tokens, as long as the prefix was matched.
     * The rest of the tokens are delayed as a function.
     */
    lexCommand(matchPrefix: MatchPrefix): [Token, () => Token[]] | null;
}
