/**
 * A type used to express computations that can fail.
 * @typeparam T - Type of results.
 * @typeparam E - Type of errors.
 */
export declare type Result<T, E> = Ok<T> | Err<E>;
/**
 * The computation is successful.
 * @typeparam T - Type of results.
 */
export interface Ok<T> {
    /**
     * Whether the computation is successful.
     */
    success: true;
    /**
     * The resulting value.
     */
    value: T;
}
/**
 * The computation failed.
 * @typeparam E - Type of errors.
 */
export interface Err<E> {
    /**
     * Whether the computation is successful.
     */
    success: false;
    /**
     * The resulting error.
     */
    error: E;
}
/**
 * Creates an Ok.
 * @typeparam T - Type of results.
 * @param x - Value to use.
 * @returns A Result.
 */
export declare function ok<T>(x: T): Ok<T>;
/**
 * Creates an Err.
 * @typeparam E - Type of errors.
 * @param x - Value to use.
 * @returns A Result.
 */
export declare function err<E>(x: E): Err<E>;
